@@ -1,10 +1,5 @@
 package App::PDFUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-17'; # DATE
-our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.007'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -12,6 +7,11 @@ use Log::ger;
 
 use Perinci::Object;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-13'; # DATE
+our $DIST = 'App-PDFUtils'; # DIST
+our $VERSION = '0.008'; # VERSION
+
 our %SPEC;
 
 my %argspec0_files = (
@@ -36,6 +36,13 @@ our %argspec0_file = (
     },
 );
 
+our %argspecopt_quiet = (
+    quiet => {
+        schema => ['bool*'],
+        cmdline_aliases => {q=>{}},
+    },
+);
+
 our %argspecopt1_output = (
     output => {
         summary => 'Output path',
@@ -257,6 +264,40 @@ sub remove_pdf_password {
     $envres->as_struct;
 }
 
+$SPEC{pdf_has_password} = {
+    v => 1.1,
+    summary => 'Check if PDF file has password',
+    args => {
+        %argspec0_file,
+        %argspecopt_quiet,
+    },
+    deps => {
+        prog => 'qpdf',
+    },
+};
+sub pdf_has_password {
+    require IPC::System::Options;
+
+    my %args = @_;
+
+    my ($stdout, $stderr);
+    IPC::System::Options::system(
+        {log => 1, fail_log_level => 'info', capture_stdout => \$stdout, capture_stderr => \$stderr},
+        "qpdf", "--check", $args{file});
+    my $has_password;
+    if ($? && $stderr =~ /: invalid password/) {
+        $has_password = 1;
+    } elsif (!$? && $stdout =~ /is not encrypted/) {
+        $has_password = 0;
+    }
+
+    [200, "OK",
+     $args{quiet} ? "" : ($has_password ? "PDF has password" : defined($has_password) ? "PDF DOES NOT have password" : "CANNOT determine if PDF has password"),
+     {
+         'cmdline.exit_code' => $has_password ? 0 : defined($has_password) ? 1 : 2,
+     }];
+}
+
 $SPEC{convert_pdf_to_text} = {
     v => 1.1,
     summary => 'Convert PDF file to text',
@@ -382,7 +423,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.007 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2021-07-17.
+This document describes version 0.008 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2021-10-13.
 
 =head1 SYNOPSIS
 
@@ -395,6 +436,8 @@ files:
 
 =item * L<grep-from-pdf>
 
+=item * L<pdf-has-password>
+
 =item * L<pdfgrep>
 
 =item * L<remove-pdf-password>
@@ -509,6 +552,42 @@ Return value:  (any)
 
 
 
+=head2 pdf_has_password
+
+Usage:
+
+ pdf_has_password(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+Check if PDF file has password.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<file>* => I<filename>
+
+Input file.
+
+=item * B<quiet> => I<bool>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
+
+
 =head2 remove_pdf_password
 
 Usage:
@@ -575,14 +654,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PDFUti
 
 Source repository is at L<https://github.com/perlancar/perl-App-PDFUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PDFUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<diff-pdf-text> from L<App::DiffPDFText>.
@@ -591,11 +662,36 @@ L<diff-pdf-text> from L<App::DiffPDFText>.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PDFUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
